#
# spec file for package xfce4-dict
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.10.0
Name:           xfce4-dict
Version:        0.8.6
Release:        1.3
Summary:        Xfce Dictionary Client Application
License:        GPL-2.0-or-later
Group:          Productivity/Office/Dictionary
URL:            https://goodies.xfce.org/projects/applications/xfce4-dict
Source:         https://archive.xfce.org/src/apps/xfce4-dict/0.8/%{name}-%{version}.tar.bz2
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gthread-2.0) >= 2.24.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.12.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.10.0
# uses xdg-open
Requires:       xdg-utils
Recommends:     %{name}-lang = %{version}
Suggests:       xfce4-panel-plugin-dict

%description
xfce4-dict allows you to search different kinds of dictionary services for
words or phrases and shows you the result. Currently you can query a Dict
server (RFC 2229), any online dictionary service by opening a web browser or
search for words using the aspell/ispell program.

%package -n xfce4-panel-plugin-dict
Summary:        Dictionary Plugin for the Xfce Panel
Group:          Productivity/Office/Dictionary
Requires:       %{name} = %{version}
Requires:       xfce4-panel >= %{panel_version}

%description -n xfce4-panel-plugin-dict
This package contains the xfce4-dict dictionary plugin for the Xfce panel.

%lang_package

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

rm %{buildroot}%{_libdir}/xfce4/panel/plugins/libxfce4dict.la

%suse_update_desktop_file -r %{name} Office Dictionary GTK

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{?no_lang_C}

%files
%doc AUTHORS ChangeLog README
%license COPYING
%{_bindir}/xfce4-dict
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/*
%{_mandir}/man1/xfce4-dict.1*

%files -n xfce4-panel-plugin-dict
%{_libdir}/xfce4/panel/plugins/libxfce4dict.so
%{_datadir}/xfce4/panel/plugins/*.desktop

%files lang -f %{name}.lang

%changelog
* Sat Nov 25 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.8.6
  * Use getaddrinfo(3) to support IPv6 DICT servers
  * Add icons at missing sizes, clean up SVG metadata
* Sun Apr 23 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.8.5
  * build: Fix -Wunused-result warning
  * Update copyright year
  * Use "logo-icon-name" instead of "logo" in about dialog
  * Remove ENABLE_NLS ifdefs
  * autoconf: Use AC_CONFIG_MACRO_DIRS
  * build: Fix intltool lock file problem during make distcheck
  * Update COPYING (Issue #7)
  * Remove unnecessary code
  * Use symbolic icons
  * Escape markup in server information
  * Replaces siginterrupt with sigaction
  * Do not close window with ctrl+c (#5)
  * Fix Text field size setting (#4)
  * Fix compilation warnings
  * autoconf: Some updates
  * Remove "." at the end of Comment string
  * Remove GSourceFunc casts
  * Include stdlib.h to get atoi prototype (!2)
  * Translation Updates
* Tue Oct 27 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.8.4
  * Update URLs and use https where possible
  * Fix font size in speedreader (gxo#apps/xfce-dict#3)
  * Added new icons and use reverse DNS file names
  * Translation Updates
* Mon Oct  7 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.8.3
  * Allow compilation with panel 4.15
  * Show correct colors (bxo#15946)
  * Avoid mnemonic conflict
  * Fix g_type_class_add_private deprecation in recent GLib
  * Replace GtkStock buttons
  * Fix typo of dict.cc (bxo#15571)
  * Fix parallel build (bxo#14963)
  * Translation Updates
- Removed deprecated macros
* Sat Dec  1 2018 sean@suspend.net
- update to version 0.8.2
  - Avoid segfaults (bxo#14786)
  - Only show web search link if we have a valid URL/dict mode
  - Escape link tooltip
  - Minor visual improvements
  - Translation updates
* Sat Jun  9 2018 seife+obs@b1-systems.com
- update to version 0.8.1
  - Bump gtk3 minimum version to 3.22
  - Improve appearance of menu items with icons
  - Append web search link to successful queries (bxo#12154)
  - Translation updates
- remove now empty %%post/%%postun, package does not build for
  pre-Leap-15 anymore anyway
* Wed Jul 19 2017 seife+obs@b1-systems.com
- update to version 0.8.0
  - Port to gtk+3/libxfce4ui-2/libxfce4panel-2.0
  - Translation updates
* Sun Dec 25 2016 seife+obs@b1-systems.com
- update to version 0.7.2
  - Translation updates
* Sun Mar 15 2015 gber@opensuse.org
- update to version 0.7.1
  - Add NEWS file
  - Correctly separate header and body (bxo#10136)
  - Update .gitignore
  - Do not build gzip tarball
  - Remove SVN $Id$ tags and update copyright year
  - Bump autotools requirements
  - Fix m4 macro dir warning
  - Fix IT_PROG_INTLTOOL warning
  - Restore git version tag
  - Remove unneeded files
  - Translation updates
* Mon May 20 2013 gber@opensuse.org
- update to version 0.7.0
  - after clearing the query_buffer, set it to NULL to prevent
    crashes
  - depend on Xfce 4.10 and its GTK/GLib requirements
  - replace libxfcegui4 by libxfce4ui
  - adapting the plugin to panel version 4.9+
  - add a 'Copy Link' menu item to the text view popup menu
  - fix Categories keyword to be more compatible
  - add a paste button to the Speed Reader
  - Quit/Close main window if Escape is pressed
  - translation updates
- dropped obsolete xfce4-dict-0.6.0-fix-wrong-callback-arg.patch
  xfce4-dict-0.6.0-use-correct-xfcepanelplugin-instance.patch
  xfce4-dict-fix-libm-underlinking.patch
* Tue Mar 12 2013 pgajdos@suse.cz
- builds with automake 1.13
  * automake-1.13.patch
* Sun Apr 29 2012 gber@opensuse.org
- add dependency on xdg-utils since xdg-open is used
* Mon Apr  2 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
* Mon Sep 19 2011 gber@opensuse.org
- added xfce4-dict-fix-libm-underlinking.patch in order to
  explicitly link against libm
* Thu Feb 17 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Fri Jan 14 2011 gber@opensuse.org
- do not require but recommend -lang subpackage
* Mon Dec 27 2010 gber@opensuse.org
- suggest xfce4-panel-plugin-dict
* Mon Dec 27 2010 gber@opensuse.org
- added xfce4-dict-0.6.0-use-correct-xfcepanelplugin-instance.patch
  and xfce4-dict-0.6.0-fix-wrong-callback-arg.patch from git fixing
  crashes
* Mon Dec 27 2010 gber@opensuse.org
- corrected group
- improved summary/description
- split off xfce4-panel-plugin-dict subpackage
- split off lang subpackge
- do not install empty NEWS
- remove unsupported locales
* Wed Dec 15 2010 prusnak@opensuse.org
- require xfce4-panel
* Wed Jan 13 2010 prusnak@suse.cz
- updated to 0.6.0
* Mon Jul 20 2009 dominique-obs@leuenberger.net
- use libexecdir instead of libdir where appropriate
* Mon May 11 2009 prusnak@suse.cz
- updated to 0.5.3
  * Reset the cursor after right-clicking on links in the textview.
  * Partly revert last change and use the proper cursor for the textview
    window again.
  * Don't allocate the default cursor unnecessarily and reuse the
    GdkWindow we already got in the event handlers.
  * Print the used dictionary in the spell checker results.
  * When using the web service fallback after a failed dictionary search,
    hide the main window if ran as panel plugin.
  * Fix untranslated search engine description (#4835).
  * Improve some strings, thanks to Jérôme Guelfucci for the suggestions.
  * Use less spacing for spell checker results and don't display any
    failed searches if used as fallback for a dictionary search.
  * Properly escape URIs when using Web based search
    (works only with GLib >= 2.16).
  * Add '--verbose' command line option for the stand-alone application.
  * When highlighting cross-references, ignore also {vr}.
  * Follow the 'Desktop Menu Specification' and change the category
    for the .desktop to 'Office'.
* Tue Feb 17 2009 prusnak@suse.cz
- updated to 0.5.2
  * When highlighting cross-references, ignore also {vr}.
  * Follow the 'Desktop Menu Specification' and change the category
    for the .desktop to 'Office'.
* Mon Nov 24 2008 prusnak@suse.cz
- updated to 0.5.1
  * Avoid leaving zombie processes when using spell checking (bug 4615).
  * Fix crashes when using the dictionary refresh button in the prefs
  dialog and while using enchant as spell checker.
  * Sort the spell check dictionary list in the prefs dialog.
  * Change bugreport address and rewrite the output of '--version'.
  * Add a 'Search' menu item to the textview popup menu for quick search
  of any text in search results.
  * Improve parsing of phonetic information, also allowing the /.../
  format, used in the Jargon dictionary.
  * Parse also phonetic information endorsed by slashes.
  Refactor some code.
  * Fix cut server responses when there is a leading number in the word
  definition (e.g. in 'moby-thes').
* Fri Nov 14 2008 prusnak@suse.cz
- updated to 0.5.0
  * Add a combo box around the search field in the main window
    to provide a history of previously searched words.
  * Add support for 'enchant' as spell check program.
  * Add a link to easily start a Web search if there are no Dict results.
  * Highlight phonetic information provided by some dictionaries.
  * Use a SexyIconEntry for the search field, it's just sexy :).
  * Add support for links (cross-references) in dictd responses.
  * Updated translations, many thanks to the translators!
* Sat Nov  1 2008 bwalle@suse.de
- Add %%dir %%{_datadir}/xfce4.
- Change categories for %%suse_update_desktop_file to pass build
  checks.
* Fri Jun 20 2008 prusnak@suse.cz
- created package (v 0.4.0)
